%define major     1.7
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           alembic
Version:        1.7.16
Release:        %mkrel 2
Summary:        Open framework for storing and sharing scene data
License:        BSD
Group:          System/Libraries
URL:            http://alembic.io/
Source0:        https://github.com/%{name}/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  pkgconfig(IlmBase)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(zlib)

%description
Alembic is an open computer graphics interchange framework. Alembic distills
complex, animated scenes into a non-procedural, application-independent set of
baked geometric results. This 'distillation' of scenes into baked geometry is
exactly analogous to the distillation of lighting and rendering scenes into
rendered image data.

#------------------------------------------------

%package -n     %{libname}
Summary:        Open framework for storing and sharing scene data
Group:          System/Libraries

%description -n %{libname}
Alembic is an open computer graphics interchange framework. Alembic distills
complex, animated scenes into a non-procedural, application-independent set of
baked geometric results. This 'distillation' of scenes into baked geometry is
exactly analogous to the distillation of lighting and rendering scenes into
rendered image data.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{develname} package contains libraries and header files for developing
applications that use %{name}.

#------------------------------------------------

%prep
%autosetup -p1

# Hardcoded library path
sed -i -e 's/INSTALL_DIR lib/INSTALL_DIR %{_lib}/g' CMakeLists.txt
sed -i \
    -e 's/INSTALL_DIR lib/INSTALL_DIR %{_lib}/g' \
    -e 's/ConfigPackageLocation lib/ConfigPackageLocation %{_lib}/g' \
    lib/Alembic/CMakeLists.txt

iconv -f iso8859-1 -t utf-8 ACKNOWLEDGEMENTS.txt > ACKNOWLEDGEMENTS.txt.conv && \
    mv -f ACKNOWLEDGEMENTS.txt.conv ACKNOWLEDGEMENTS.txt

%build
%cmake \
    -DALEMBIC_SHARED_LIBS=ON \
    -DUSE_BINARIES=ON \
    -DUSE_HDF5=ON \
    -DUSE_EXAMPLES=ON \
    -DUSE_PYALEMBIC=OFF \
    -DUSE_STATIC_BOOST=OFF \
    -DUSE_STATIC_HDF5=OFF \
    -DUSE_TESTS=ON

%cmake_build

%install
%cmake_install

%files
%doc ACKNOWLEDGEMENTS.txt FEEDBACK.txt NEWS.txt README.txt
%license LICENSE.txt
%{_bindir}/abcconvert
%{_bindir}/abcdiff
%{_bindir}/abcecho
%{_bindir}/abcechobounds
%{_bindir}/abcls
%{_bindir}/abcstitcher
%{_bindir}/abctree

%files -n %{libname}
%{_libdir}/libAlembic.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/Alembic/
%{_libdir}/cmake/Alembic/
%{_libdir}/libAlembic.so


%changelog
* Sat Jan 09 2021 daviddavid <daviddavid> 1.7.16-2.mga8
+ Revision: 1670047
- rebuild for new hdf5 1.10.7

* Wed Oct 28 2020 daviddavid <daviddavid> 1.7.16-1.mga8
+ Revision: 1640014
- new version: 1.7.16

* Wed Oct 21 2020 daviddavid <daviddavid> 1.7.15-1.mga8
+ Revision: 1637470
- new version: 1.7.15

* Wed Sep 09 2020 akien <akien> 1.7.13-2.mga8
+ Revision: 1623789
- Rebuild for new OpenEXR/Ilm

* Tue Jul 14 2020 daviddavid <daviddavid> 1.7.13-1.mga8
+ Revision: 1605900
- new version: 1.7.13

* Mon Feb 17 2020 umeabot <umeabot> 1.7.12-2.mga8
+ Revision: 1537225
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Oct 27 2019 daviddavid <daviddavid> 1.7.12-1.mga8
+ Revision: 1456035
- new version: 1.7.12

* Fri May 24 2019 daviddavid <daviddavid> 1.7.11-1.mga7
+ Revision: 1398996
- new version: 1.7.11

* Sat Jan 12 2019 daviddavid <daviddavid> 1.7.10-1.mga7
+ Revision: 1355572
- new version: 1.7.10

* Thu Nov 08 2018 daviddavid <daviddavid> 1.7.9-3.mga7
+ Revision: 1328898
- rebuild for new hdf5 1.10.4

* Mon Oct 15 2018 daviddavid <daviddavid> 1.7.9-2.mga7
+ Revision: 1320422
- rebuild for new ilmbase 2.3.0

* Sat Oct 06 2018 daviddavid <daviddavid> 1.7.9-1.mga7
+ Revision: 1318283
- new version: 1.7.9

* Fri Sep 21 2018 umeabot <umeabot> 1.7.8-2.mga7
+ Revision: 1294278
- Mageia 7 Mass Rebuild

* Thu May 17 2018 daviddavid <daviddavid> 1.7.8-1.mga7
+ Revision: 1230173
- new version: 1.7.8

* Mon Mar 26 2018 daviddavid <daviddavid> 1.7.7-1.mga7
+ Revision: 1212629
- new version: 1.7.7

* Mon Mar 26 2018 daviddavid <daviddavid> 1.7.5-1.mga7
+ Revision: 1212617
- initial package alembic

